@@ -1,5 +1,5 @@
 <?php if (!defined('PmWiki')) exit();
-/*  Copyright 2004-2025 Patrick R. Michaud (pmichaud@pobox.com)
+/*  Copyright 2004-2026 Patrick R. Michaud (pmichaud@pobox.com)
     This file is part of PmWiki; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2 of the License, or
@@ -544,3 +544,26 @@ function AttachExist($pagename, $condparm='*') {
   }
   return count($flist);
 }
+
+$MarkupDirectiveFunctions['dropzone'] = 'FmtDropZone';
+function FmtDropZone($pagename, $d, $args) {
+  global $EnableUploadDrop, $Author;
+  if (!IsEnabled($EnableUploadDrop, 0)) return '';
+  SDVA($args, [
+    'uploadpage'  => $pagename,
+    'label' => XL('ULdroplabel'),
+    'class' => 'frame',
+  ]);
+  $pn = MakePageName($pagename, $args['uploadpage']);
+  $canupload = CondAuth($pn, 'upload', true);
+  if(!$canupload) return '';
+  $conf = [
+    'n'=>$pn,
+    'action'=>FmtPageName('{$PageUrl}?action=postupload&pmdrop=1', $pn),
+    'author' => $Author,
+  ];
+  $json = pm_json_encode($conf, true);
+  $eargs = PHSCQF($args);
+  return KeepBlock("<div class=\"pmdropzone {$eargs['class']}\" data-pmdropzone=\"$json\">
+  <span>{$eargs['label']}&nbsp;</span></div>");
+}
